//  Copyright (C) SystemTools Software Inc. All Rights Reserved.
//
//
//  The STRCM utility is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
//  USA.
//
//  Further information on this software can be obtained from:
//
//  http://www.systemtools.com/strcm_frame.htm
//  
//  Additional contact and support information is available at this site.

// strcmDlg.cpp : implementation file
//

#include "stdafx.h"
#include "strcm.h"
#include "strcmDlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CStrcmDlg dialog

CStrcmDlg::CStrcmDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CStrcmDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CStrcmDlg)
	m_FileName = _T("");
	m_Operation = -1;
	m_Host = _T("");
	//}}AFX_DATA_INIT
	// Note that LoadIcon does not require a subsequent DestroyIcon in Win32
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}

void CStrcmDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CStrcmDlg)
	DDX_Control(pDX, IDOK, m_cOK);
	DDX_Control(pDX, IDCANCEL, m_cCancel);
	DDX_Control(pDX, IDC_MSG, m_cMsg);
	DDX_Text(pDX, IDC_FILENAME, m_FileName);
	DDX_Radio(pDX, IDC_OPERATION, m_Operation);
	DDX_Text(pDX, IDC_HOST, m_Host);
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CStrcmDlg, CDialog)
	//{{AFX_MSG_MAP(CStrcmDlg)
	ON_WM_PAINT()
	ON_WM_QUERYDRAGICON()
	ON_BN_CLICKED(IDC_FIND, OnFind)
	ON_BN_CLICKED(IDC_HELP, OnHelp)
	ON_BN_CLICKED(IDC_CLEAR, OnClear)
	ON_BN_CLICKED(ID_HELP, OnHelp)
	ON_BN_CLICKED(IDC_EDIT, OnEdit)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CStrcmDlg message handlers

BOOL CStrcmDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon
	
	m_wndLink1.SubclassDlgItem(IDC_WEBURL, this);	

	if (m_Operation == -1)
		m_Operation = 0;

	UpdateData(FALSE);
	
	return TRUE;
}

// If you add a minimize button to your dialog, you will need the code below
//  to draw the icon.  For MFC applications using the document/view model,
//  this is automatically done for you by the framework.

void CStrcmDlg::OnPaint() 
{
	if (IsIconic())
	{
		CPaintDC dc(this); // device context for painting

		SendMessage(WM_ICONERASEBKGND, (WPARAM) dc.GetSafeHdc(), 0);

		// Center icon in client rectangle
		int cxIcon = GetSystemMetrics(SM_CXICON);
		int cyIcon = GetSystemMetrics(SM_CYICON);
		CRect rect;
		GetClientRect(&rect);
		int x = (rect.Width() - cxIcon + 1) / 2;
		int y = (rect.Height() - cyIcon + 1) / 2;

		// Draw the icon
		dc.DrawIcon(x, y, m_hIcon);
	}
	else
		CDialog::OnPaint();

	// here is where we run the code automatically (but only once), if certain conditions were
	// met when we started up:
	// - all parameters were supplied
	// - the ConfirmParameters setting is set to FALSE
	if (m_AutoRun)
	{
		m_AutoRun = FALSE;
		UpdateWindow();
		OnOK();
	}
}

// The system calls this to obtain the cursor to display while the user drags
//  the minimized window.
HCURSOR CStrcmDlg::OnQueryDragIcon()
{
	return (HCURSOR) m_hIcon;
}

void CStrcmDlg::OnFind() 
{
	UpdateData(TRUE);
	CFileDialog dlg (TRUE, NULL, NULL, OFN_PATHMUSTEXIST, _T("Remote Control Manager (*.rcm)|*.rcm"), this);
	if (dlg.DoModal() == IDOK)
	{
		m_FileName = dlg.GetPathName();
		UpdateData(FALSE);
	}
	
}

void CStrcmDlg::OnHelp() 
{
	CString temp = m_App->GetCurrentDir() + "strcm.htm";
	ShellExecute(NULL, "open", temp, NULL, NULL, SW_SHOW);
}

void CStrcmDlg::OnOK() 
{
	UpdateData(TRUE);

	// if there isn't any path to the file, we need to set the working directory to be
	// the current directory
	if (m_FileName.Find('\\') == -1)
		m_FileName = m_App->GetCurrentDir() + m_FileName;
	
	// make sure the file exits, or the settings will be junk
	if (!m_App->CheckIfExists(m_FileName))
	{
		CString Error;
		Error.Format(IDS_MISSING_RCM_FILE, m_FileName);
		m_App->ReportError(Error);
		return;
	}

	BeginWaitCursor();
	switch (m_Operation)
	{
	case 0: // view
		m_App->RemoteViewer(m_FileName, m_Host, &m_cMsg);
		break;
	case 1: // install
		m_App->RemoteInstall(m_FileName, m_Host, &m_cMsg);
		break;
	case 2: // uninstall
		m_App->RemoteUnInstall(m_FileName, m_Host, &m_cMsg);
		break;
	case 3: // options
		m_App->SetOptions(m_FileName, m_Host, &m_cMsg);
		break;
	case 4: // start service
		m_App->StartServiceOperation(m_FileName, m_Host, &m_cMsg);
		break;
	case 5: // stop service
		m_App->StopServiceOperation(m_FileName, m_Host, &m_cMsg);
		break;
	}
	// it seemed annoying to autoterminate after anything but a view...
	//if (m_Operation != 0) // if not a view...we terminate this app in the View routine
	//{
	//	if (m_AutoTerminate)
	//		OnCancel();
	//}
	EndWaitCursor();
}

void CStrcmDlg::Exit()
{
	OnCancel();
}

void CStrcmDlg::OnClear() 
{
	m_cMsg.ResetContent();
}

void CStrcmDlg::OnCancel() 
{
	CDialog::OnCancel();
}

void CStrcmDlg::OnEdit() 
{
	UpdateData(TRUE);

	CString Cmd = m_FileName;
	if (Cmd.Find('\\') == -1)
		Cmd = m_App->GetCurrentDir() + Cmd;
	Cmd = "notepad " + Cmd;

	STARTUPINFO si;
	PROCESS_INFORMATION pi;

	ZeroMemory(&si, sizeof(si));
	si.cb = sizeof(si);
	si.dwFlags = STARTF_FORCEONFEEDBACK; 
	si.wShowWindow = SW_SHOW;

	BOOL BOOLres = CreateProcess(NULL, (LPTSTR) ((LPCTSTR) Cmd), NULL, NULL, FALSE, 
			          NORMAL_PRIORITY_CLASS, NULL, NULL, &si, &pi);
	if (BOOLres != FALSE)
	{
		CloseHandle(pi.hProcess);
		CloseHandle(pi.hThread);
	}
}
